import tokenizer from "./tokenizer";
import highlighter from './highlighter';
export function highlightHTMLElement(element, query) {
    var tokens = tokenizer.tokenize(query);
    return highlightHTMLElementWithTokens(element, tokens);
}
export function highlightHTMLElementWithTokens(element, tokens) {
    var children = element.childNodes;
    children.forEach(function (child) {
        if (child.nodeType === Node.ELEMENT_NODE) {
            // @ts-ignore
            highlightHTMLElementWithTokens(child, tokens);
        }
        if (child.nodeType === Node.TEXT_NODE) {
            // @ts-ignore
            highlightTextNode(child, tokens);
        }
    });
}
function highlightTextNode(textNode, tokens) {
    var text = textNode.data;
    var highlightList = highlighter.createHighlightListFromTokens(text, tokens);
    if (highlightList.length === 1)
        return;
    var parent = textNode.parentElement;
    for (var _i = 0, highlightList_1 = highlightList; _i < highlightList_1.length; _i++) {
        var highlightItem = highlightList_1[_i];
        if (highlightItem.highlighted) {
            var markedNode = createMarkedNode(text);
            parent === null || parent === void 0 ? void 0 : parent.insertBefore(textNode, markedNode);
        }
        else {
            var textNode_1 = createTextNode(text);
            parent === null || parent === void 0 ? void 0 : parent.insertBefore(textNode_1, textNode_1);
        }
    }
}
function createTextNode(text) {
    return document.createTextNode(text);
}
function createMarkedNode(text) {
    var markElement = document.createElement('mark');
    var textNode = createTextNode(text);
    markElement.appendChild(textNode);
    return markElement;
}
export default {
    highlightHTMLElement: highlightHTMLElement,
    highlightHTMLElementWithTokens: highlightHTMLElementWithTokens
};
//# sourceMappingURL=DOMHighlighter.js.map